Ohmu
====

View space usage in your terminal.

.. image:: https://img.shields.io/travis/paul-nechifor/ohmu.svg?style=flat-square
    :target: https://travis-ci.org/paul-nechifor/ohmu

.. image:: https://img.shields.io/codecov/c/github/paul-nechifor/ohmu.svg?style=flat-square
    :target: https://codecov.io/github/paul-nechifor/ohmu

.. image:: https://img.shields.io/pypi/v/ohmu.svg?style=flat-square
    :target: https://pypi.python.org/pypi/ohmu

.. image:: https://img.shields.io/pypi/dm/ohmu.svg?style=flat-square
    :target: https://pypi.python.org/pypi/ohmu

.. image:: https://img.shields.io/pypi/l/ohmu.svg?style=flat-square
    :target: http://opensource.org/licenses/MIT
